//! # Tinify Crate
//!
//! `tinify-rs` is a Rust client for the Tinify API.
//! Used for TinyPNG and TinyJPG. Tinify compresses your images intelligently.
//!
//! Read more at https://tinify.com
// --snip--

mod error;
mod mock;
mod client;
mod result;
mod source;
pub mod tinify;
